GoogleSearch_services

|  | ## Cheshire3:

# Module GoogleSearch_services

## Classes

GoogleSearchBindingSOAP

GoogleSearchServiceInterface

GoogleSearchServiceLocator

doGetCachedPage

doGetCachedPageResponse

doGetCachedPageResponseWrapper

doGetCachedPageWrapper

doGoogleSearch

doGoogleSearchResponse

doGoogleSearchResponseWrapper

doGoogleSearchWrapper

doSpellingSuggestion

doSpellingSuggestionResponse

doSpellingSuggestionResponseWrapper

doSpellingSuggestionWrapper

[hide private]